@@ -5,6 +5,9 @@ import multiprocessing
 import os
 import sys
 
+from .util import AWS_ENV_VARS
+from .cfngin.session_cache import get_session
+
 LOGGER = logging.getLogger('runway')
 
 
@@ -44,12 +47,30 @@ class Context(object):
         self.command = command
         self.env_vars = env_vars or os.environ.copy()
         self._env_name_from_env = bool(self.env_vars.get(self.env_override_name))
+        self.debug = bool(self.env_vars.get('DEBUG'))
 
         self.echo_detected_environment()
 
         if not self._env_name_from_env:
             self.env_vars.update({'DEPLOY_ENVIRONMENT': self.env_name})
 
+    @property
+    def boto3_credentials(self):
+        """Return a dict of boto3 credentials."""
+        return {key.lower(): value
+                for key, value in self.current_aws_creds.items()}
+
+    @property
+    def current_aws_creds(self):
+        """AWS credentials from self.env_vars.
+
+        Returns:
+            Dict[str, str]
+
+        """
+        return {name: self.env_vars.get(name)
+                for name in AWS_ENV_VARS if self.env_vars.get(name)}
+
     @property
     def is_interactive(self):
         """Wether the user should be prompted or not.
@@ -85,7 +106,23 @@ class Context(object):
             bool
 
         """
-        return sys.version_info[0] > 2
+        return sys.version_info.major > 2
+
+    @property
+    def max_concurrent_cfngin_stacks(self):
+        """Max number of CFNgin stacks that can be deployed concurrently.
+
+        This property can be set by exporting
+        ``RUNWAY_MAX_CONCURRENT_CFNGIN_STACKS``. If no value is specified, the
+        value will be constrained based on the underlying graph.
+
+        Returns:
+            int: Value from environment variable or ``0``.
+
+        """
+        return int(
+            self.env_vars.get('RUNWAY_MAX_CONCURRENT_CFNGIN_STACKS', '0')
+        )
 
     @property
     def max_concurrent_modules(self):
@@ -104,7 +141,7 @@ class Context(object):
             int: Value from environment variable or ``min(61, os.cpu_count())``
 
         """
-        value = os.getenv('RUNWAY_MAX_CONCURRENT_MODULES')
+        value = self.env_vars.get('RUNWAY_MAX_CONCURRENT_MODULES')
 
         if value:
             return int(value)
@@ -128,7 +165,7 @@ class Context(object):
             int: Value from environment variable or ``min(61, os.cpu_count())``
 
         """
-        value = os.getenv('RUNWAY_MAX_CONCURRENT_REGIONS')
+        value = self.env_vars.get('RUNWAY_MAX_CONCURRENT_REGIONS')
 
         if value:
             return int(value)
@@ -172,17 +209,40 @@ class Context(object):
                         "the %s environment variable", self.env_override_name)
         LOGGER.info("")
 
+    def get_session(self, profile=None, region=None):
+        """Create a thread-safe boto3 session.
+
+        Args:
+            profile (Optional[str]): The profile for the session.
+            region (Optional[str]): The region for the session.
+
+        Returns:
+            :class:`boto3.session.Session`: A thread-safe boto3 session.
+
+        """
+        kwargs = {}
+        # save to var so its not calculated multiple times
+        creds = self.boto3_credentials
+        if profile:
+            kwargs['profile'] = profile
+        elif creds:
+            kwargs.update({
+                'access_key': creds.get('aws_access_key_id'),
+                'secret_key': creds.get('aws_secret_access_key'),
+                'session_token': creds.get('aws_session_token')
+            })
+            LOGGER.warning('Current env_region: %s', self.env_region)
+        return get_session(region=region or self.env_region, **kwargs)
+
     def save_existing_iam_env_vars(self):
         """Backup IAM environment variables for later restoration."""
-        for i in ['AWS_ACCESS_KEY_ID', 'AWS_SECRET_ACCESS_KEY',
-                  'AWS_SESSION_TOKEN']:
+        for i in AWS_ENV_VARS:
             if i in self.env_vars:
                 self.env_vars['OLD_' + i] = self.env_vars[i]
 
     def restore_existing_iam_env_vars(self):
         """Restore backed up IAM environment variables."""
-        for i in ['AWS_ACCESS_KEY_ID', 'AWS_SECRET_ACCESS_KEY',
-                  'AWS_SESSION_TOKEN']:
+        for i in AWS_ENV_VARS:
             if 'OLD_' + i in self.env_vars:
                 self.env_vars[i] = self.env_vars['OLD_' + i]
             elif i in self.env_vars:
