@@ -5,6 +5,7 @@ from typing import Any, Dict, Iterator, List, Optional, Union  # noqa pylint: di
 from contextlib import contextmanager
 import hashlib
 import importlib
+import json
 import os
 import platform
 import re
@@ -13,12 +14,49 @@ from subprocess import check_call
 import sys
 import six
 
+AWS_ENV_VARS = ('AWS_ACCESS_KEY_ID', 'AWS_SECRET_ACCESS_KEY',
+                'AWS_SESSION_TOKEN')
 EMBEDDED_LIB_PATH = os.path.join(
     os.path.dirname(os.path.abspath(__file__)),
     'embedded'
 )
 
 
+class cached_property(object):  # noqa pylint: disable=invalid-name,too-few-public-methods
+    """Decorator for creating cached properties.
+
+    A property that is only computed once per instance and then replaces itself
+    with an ordinary attribute. Deleting the attribute resets the property.
+    Source: https://github.com/bottlepy/bottle/commit/fa7733e075da0d790d809aa3d2f53071897e6f76
+
+    """
+
+    def __init__(self, func):
+        """Initialize class.
+
+        Args:
+            func (Callable): Method being decorated.
+
+        """
+        self.func = func
+
+    def __get__(self, obj, _):
+        """Attempt to get a cached value.
+
+        Args:
+            obj (Any): Instance of a class.
+
+        Returns:
+            Any
+
+        """
+        if obj is None:
+            return self
+
+        value = obj.__dict__[self.func.__name__] = self.func(obj)
+        return value
+
+
 # python2 supported pylint is unable to load six.moves correctly
 class MutableMap(six.moves.collections_abc.MutableMapping):  # pylint: disable=no-member
     """Base class for mutable map objects."""
@@ -86,6 +124,11 @@ class MutableMap(six.moves.collections_abc.MutableMapping):  # pylint: disable=n
             ignore_cache: Ignore cached value.
 
         """
+        if not hasattr(self, '_found_queries'):
+            # if not created from kwargs, this attr won't exist yet
+            # this is done to prevent endless recursion
+            self._found_queries = MutableMap()
+
         if not ignore_cache:
             cached_result = self._found_queries.get(query, None)
             if cached_result:
@@ -133,6 +176,11 @@ class MutableMap(six.moves.collections_abc.MutableMapping):  # pylint: disable=n
             return True
         return False
 
+    def __contains__(self, value):
+        # type: () -> bool
+        """Implement evaluation of 'in' conditional."""
+        return value in self.data
+
     __nonzero__ = __bool__  # python2 compatability
 
     def __getitem__(self, key):
@@ -227,6 +275,11 @@ class MutableMap(six.moves.collections_abc.MutableMapping):  # pylint: disable=n
         """
         return iter(self.__dict__)
 
+    def __str__(self):
+        # type: () -> str
+        """Return string representation of the object."""
+        return json.dumps(self.data)
+
 
 @contextmanager
 def change_dir(newdir):
